from setuptools import setup

setup(name='xdspider',
      version='0.1',
      description='Python Web Spider',
      url='http://github.com/storborg/funniest',
      author='Dean Van Greunen',
      author_email='deanvg9000@gmail.com',
      license='GPL v3',
      packages=['xdspider'],
      zip_safe=False)